local mod = ...



-- Starting Inventory -------------------------------------------------------------------------------------
mod:overrideAsset({
	Id = "DEFAULT_VILLAGE_CENTER_INVENTORY",
	Collection = {
        Action = "APPEND",
        {Resource = "PLANK", Quantity = 100},
    },
})



-- Stones -------------------------------------------------------------------------------------
local function registerStone(meshName, prefabName, resourceName, plantingDistance, radiusDistance, resourceQty, availableQty)

    mod:registerAssetId("models/Bush1.fbx/Prefab/" .. meshName, prefabName)
    mod:registerPrefabComponent("models/Bush1.fbx/Prefab/" .. meshName, { DataType = "COMP_PLANTABLE", MinSpaceBetweenPlant = plantingDistance })
    mod:registerPrefabComponent("models/Bush1.fbx/Prefab/" .. meshName, { DataType = "COMP_TREE" })

    mod:registerAsset({
        DataType = "PLANTABLE",
        Id = "PLANTABLE_" .. prefabName,
        Name = "PLANTABLE_" .. prefabName,
        PlantPrefab = prefabName,
        Icon = "ICON_RESOURCE_" .. resourceName,
        MinimumScale = 0.85, -- min size at full growth
        MaximumScale = 1.15 -- max size at full growth
    })

    mod:registerPrefabComponent( "models/Bush1.fbx/Prefab/" .. meshName, {
        DataType = "COMP_RESOURCE_CONTAINER",
        ResourceData = resourceName,
        IsReplenishable = false,
        ResourceValue = resourceQty, -- how many are gathered with each pick
        AvailableQuantity = availableQty, -- maximum container stock
        Radius = radiusDistance, -- distance from container that the villager will stand to pick
        IsDestroyWhenEmpty = true,
    })

end

registerStone("Stone.001", "PREFAB_AALSMEER_STONE1", "STONE", 1, 1.2, 1, 10)
registerStone("Stone.002", "PREFAB_AALSMEER_STONE2", "STONE", 1, 1.2, 1, 14)
registerStone("Stone.003", "PREFAB_AALSMEER_STONE3", "STONE", 1, 1.2, 1, 8)
registerStone("Stone.004", "PREFAB_AALSMEER_STONE4", "STONE", 1, 1.2, 1, 10)
registerStone("Stone.005", "PREFAB_AALSMEER_STONE5", "STONE", 1, 1.2, 1, 16)



-- Minerals -------------------------------------------------------------------------------------
local function registerMineral(meshName, prefabName, resourceName, plantingDistance, radiusDistance, resourceQty, availableQty)

    mod:registerAssetId("models/Mineral1.fbx/Prefab/" .. meshName, prefabName)
    mod:registerPrefabComponent("models/Mineral1.fbx/Prefab/" .. meshName, { DataType = "COMP_PLANTABLE", MinSpaceBetweenPlant = plantingDistance })
    mod:registerPrefabComponent("models/Mineral1.fbx/Prefab/" .. meshName, { DataType = "COMP_TREE" })

    mod:registerAsset({
        DataType = "PLANTABLE",
        Id = "PLANTABLE_" .. prefabName,
        Name = "PLANTABLE_" .. prefabName,
        PlantPrefab = prefabName,
        Icon = "ICON_RESOURCE_" .. resourceName,
        MinimumScale = 0.85, -- min size at full growth
        MaximumScale = 1.15 -- max size at full growth
    })

    mod:registerPrefabComponent( "models/Mineral1.fbx/Prefab/" .. meshName, {
        DataType = "COMP_RESOURCE_CONTAINER",
        ResourceData = resourceName,
        IsReplenishable = false,
        ResourceValue = resourceQty, -- how many are gathered with each pick
        AvailableQuantity = availableQty, -- maximum container stock
        Radius = radiusDistance, -- distance from container that the villager will stand to pick
        IsDestroyWhenEmpty = true,
    })

end

registerMineral("Gold.001", "PREFAB_AALSMEER_GOLD1", "GOLD_ORE", 1, 3.5, 1, 100)
registerMineral("Gold.002", "PREFAB_AALSMEER_GOLD2", "GOLD_ORE", 1, 3.5, 1, 100)
registerMineral("Gold.003", "PREFAB_AALSMEER_GOLD3", "GOLD_ORE", 1, 3.5, 1, 100)
registerMineral("Iron.001", "PREFAB_AALSMEER_IRON1", "IRON_ORE", 1, 2.0, 1, 60)
registerMineral("Iron.002", "PREFAB_AALSMEER_IRON2", "IRON_ORE", 1, 2.0, 1, 60)
registerMineral("Iron.003", "PREFAB_AALSMEER_IRON3", "IRON_ORE", 1, 2.0, 1, 60)
registerMineral("Quartz.001", "PREFAB_AALSMEER_QUARTZ1", "QUARTZ", 1, 2.5, 1, 100)
registerMineral("Quartz.002", "PREFAB_AALSMEER_QUARTZ2", "QUARTZ", 1, 2.5, 1, 100)
registerMineral("Quartz.003", "PREFAB_AALSMEER_QUARTZ3", "QUARTZ", 1, 2.5, 1, 100)
registerMineral("Marble.001", "PREFAB_AALSMEER_MARBLE1", "MARBLE", 1, 3.5, 1, 120)
registerMineral("Marble.002", "PREFAB_AALSMEER_MARBLE2", "MARBLE", 1, 3.5, 1, 120)
registerMineral("Marble.003", "PREFAB_AALSMEER_MARBLE3", "MARBLE", 1, 3.5, 1, 120)




-- Maps -------------------------------------------------------------------------------------
mod:registerAssetId("maps/heightmap.png", "HEIGHT_MAP")
mod:registerAssetId("maps/material_mask.png", "MATERIAL_MASK")
mod:registerAssetId("maps/fish_density.png", "FISH_DENSITY_MAP")
mod:registerAssetId("maps/tree_density.png", "TREE_MAP")
mod:registerAssetId("maps/berries_density.png", "BERRIES_MAP")
mod:registerAssetId("maps/stone_density.png", "STONE_MAP")
mod:registerAssetId("maps/iron_density.png", "IRON_MAP")
mod:registerAssetId("maps/gold_density.png", "GOLD_MAP")
mod:registerAssetId("maps/quartz_density.png", "QUARTZ_MAP")
mod:registerAssetId("maps/marble_density.png", "MARBLE_MAP")



-- Register custom map
mod:registerAsset({
	DataType = "CUSTOM_MAP",
	Id = "MAP_AALSMEER",
	HeightMap = "HEIGHT_MAP",
	MaterialMask = "MATERIAL_MASK",
	MinHeight = -3,
	MaxHeight = 8,
	VillagePathList = {
		{
			Entrance = { 8, 0, 950 },
			Exit = { 270, 0, 5 },
		},
		{
			Entrance = { 251, 0, 1011 },
			Exit = { 708, 0, 8 },
		},
		{
			Entrance = { 547, 0, 1008 },
			Exit = { 285, 0, 4 },
		},
		{
			Entrance = { 830, 0, 1011 },
			Exit = { 722, 0, 6 },
		},
		{
			Entrance = { 907, 0, 1007 },
			Exit = { 869, 0, 7 },
		},
		{
			Entrance = { 9, 0, 710 },
			Exit = { 1015, 0, 581 },
		},
		{
			Entrance = { 10, 0, 586 },
			Exit = { 1016, 0, 904 },
		}
	},

    SpawnList = {
	},

    DensitySpawnList = {

        {
			-- Trees
			DensityMap = "TREE_MAP",
			Density = 0.9,
			PrefabConfigList = {
				{
                        PrefabList = { "PREFAB_TREE_OAK" },
                        RandomWeight = 2.0,
                        OffsetSizeRange = {
                            Min = 0.75,
                            Max = 1.25
                    },
                        OrientationRange = {
                            Min = { 0, -180, 0 },
                            Max = { 0, 180, 0 }
                    },
                        ScaleRange = {
                            Min = 0.75,
                            Max = 1.25
                    },
                        ColorRange = {
                            Min = { 0.8,0.8,0.8,1 },
                            Max = { 1,1,1,1 }
                    },
                },
                {
                        PrefabList = { "PREFAB_TREE_SYCAMORE" },
                        RandomWeight = 1.0,
                        OffsetSizeRange = {
                            Min = 0.75,
                            Max = 1.25
                    },
                        OrientationRange = {
                            Min = { 0, -180, 0 },
                            Max = { 0, 180, 0 }
                    },
                        ScaleRange = {
                            Min = 0.75,
                            Max = 1.25
                    },
                        ColorRange = {
                            Min = { 0.8,0.8,0.8,1 },
                            Max = { 1,1,1,1 }
                    },
                },
                {
                        PrefabList = { "PREFAB_TREE_POPLAR" },
                        RandomWeight = 0.5,
                        OffsetSizeRange = {
                            Min = 0.75,
                            Max = 1.25
                    },
                        OrientationRange = {
                            Min = { 0, -180, 0 },
                            Max = { 0, 180, 0 }
                    },
                        ScaleRange = {
                            Min = 0.75,
                            Max = 1.25
                    },
                        ColorRange = {
                            Min = { 0.8,0.8,0.8,1 },
                            Max = { 1,1,1,1 }
                    },
                },
            },
		},


        {
			-- Stones (small amount of stone, inhibits farming until cleared)
			DensityMap = "STONE_MAP",
			Density = 0.6,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_AALSMEER_STONE1" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_AALSMEER_STONE2" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_AALSMEER_STONE3" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_AALSMEER_STONE4" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_AALSMEER_STONE5" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
			}
		},

		{
			-- Gold ore
			DensityMap = "GOLD_MAP",
			Density = 0.5,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_AALSMEER_GOLD1" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 }
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                },
				{
                    PrefabList = { "PREFAB_AALSMEER_GOLD2" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 }
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                },
				{
                    PrefabList = { "PREFAB_AALSMEER_GOLD3" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 }
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                },
			}
		},

        {
			-- Iron ore
			DensityMap = "IRON_MAP",
			Density = 0.85,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_AALSMEER_IRON1" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 }
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                },
				{
                    PrefabList = { "PREFAB_AALSMEER_IRON2" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 }
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                },
				{
                    PrefabList = { "PREFAB_AALSMEER_IRON3" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 }
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                },
			}
		},

        {
			-- Quartz
			DensityMap = "QUARTZ_MAP",
			Density = 0.5,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_AALSMEER_QUARTZ1" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 }
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                },
				{
                    PrefabList = { "PREFAB_AALSMEER_QUARTZ2" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 }
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                },
				{
                    PrefabList = { "PREFAB_AALSMEER_QUARTZ3" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 }
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                },
			}
		},

        {
			-- Marble
			DensityMap = "MARBLE_MAP",
			Density = 0.35,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_AALSMEER_MARBLE1" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 }
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                },
				{
                    PrefabList = { "PREFAB_AALSMEER_MARBLE2" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 }
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                },
				{
                    PrefabList = { "PREFAB_AALSMEER_MARBLE3" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 }
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                },
			}
		},

        {
			-- Fish
			DensityMap = "FISH_DENSITY_MAP",
			Density = 0.9,
			PrefabConfigList = {
				{
						PrefabList = { "PREFAB_RESOURCE_FISH" },
						RandomWeight = 0.1,
						OffsetSizeRange = {
                            Min = 0.75,
                            Max = 1.00,
                        },
						OrientationRange = {
							Min = { 0, -180, 0 },
							Max = { 0, 180, 0 }
					},
						ScaleRange = {
							Min = 0.85,
							Max = 1.15
					},
						ColorRange = {
							Min = { 0.8, 0.8, 0.8, 1 },
							Max = { 1, 1, 1, 1 }
					}
				}
			}
		},

        {
			-- Berries
			DensityMap = "BERRIES_MAP",
			Density = 0.9,
			PrefabConfigList = {
				{
						PrefabList = { "PREFAB_RESOURCE_BERRIES" },
						RandomWeight = 0.1,
						OffsetSizeRange = {
                            Min = 0.75,
                            Max = 1.00,
                        },
						OrientationRange = {
							Min = { 0, -180, 0 },
							Max = { 0, 180, 0 }
					},
						ScaleRange = {
							Min = 0.85,
							Max = 1.15
					},
						ColorRange = {
							Min = { 0.8, 0.8, 0.8, 1 },
							Max = { 1, 1, 1, 1 }
					}
				}
			}
		},

	}
})



